@@ -16,4 +16,4 @@ def cal_page_count(total_count: int, per_page_count: int) -> int:
         else:
             return total_count // per_page_count if total_count % per_page_count == 0 else total_count // per_page_count + 1
     else:
-        raise ValueError("总条数total_count必须>=0，每页数量per_page_count>0")
+        raise ValueError("总条数total_count必须>=0，每页数量per_page_count必须>0")
